==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/InstanceHandleSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;
import io.ciera.tool.sql.ooaofooa.value.InstanceHandle;
import io.ciera.tool.sql.ooaofooa.value.InstanceHandleSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.List;


public class InstanceHandleSetImpl extends InstanceSet<InstanceHandleSet,InstanceHandle> implements InstanceHandleSet {

    // attributes
    @Override
    public void setIsImplicitInFor( boolean m_IsImplicitInFor ) throws XtumlException {
        for ( InstanceHandle instancehandle : this ) instancehandle.setIsImplicitInFor( m_IsImplicitInFor );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( InstanceHandle instancehandle : this ) instancehandle.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( InstanceHandle instancehandle : this ) instancehandle.setVar_ID( ref_Var_ID );
    }


    // selections
    @Override
    public V_VARSet R814_is_a_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( InstanceHandle instancehandle : this ) v_varset.add( instancehandle.R814_is_a_V_VAR() );
        return v_varset;
    }
    @Override
    public ModelClassSet R818_refers_to_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( InstanceHandle instancehandle : this ) modelclassset.add( instancehandle.R818_refers_to_ModelClass() );
        return modelclassset;
    }


    @Override
    public InstanceHandle nullElement() {
        return InstanceHandleImpl.EMPTY_INSTANCEHANDLE;
    }

    @Override
    public InstanceHandleSet emptySet() {
      return new InstanceHandleSetImpl();
    }

    @Override
    public InstanceHandleSet value() {
        return this;
    }

    @Override
    public List<InstanceHandle> elements() {
        return Arrays.asList(toArray(new InstanceHandle[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/InstanceHandleSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;
import io.ciera.tool.sql.ooaofooa.value.InstanceHandle;
import io.ciera.tool.sql.ooaofooa.value.InstanceHandleSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InstanceHandleSetImpl extends InstanceSet<InstanceHandleSet,InstanceHandle> implements InstanceHandleSet {

    public InstanceHandleSetImpl() {
    }

    public InstanceHandleSetImpl(Comparator<? super InstanceHandle> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( InstanceHandle instancehandle : this ) instancehandle.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setIsImplicitInFor( boolean m_IsImplicitInFor ) throws XtumlException {
        for ( InstanceHandle instancehandle : this ) instancehandle.setIsImplicitInFor( m_IsImplicitInFor );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( InstanceHandle instancehandle : this ) instancehandle.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public V_VARSet R814_is_a_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( InstanceHandle instancehandle : this ) v_varset.add( instancehandle.R814_is_a_V_VAR() );
        return v_varset;
    }
    @Override
    public ModelClassSet R818_refers_to_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( InstanceHandle instancehandle : this ) modelclassset.add( instancehandle.R818_refers_to_ModelClass() );
        return modelclassset;
    }


    @Override
    public InstanceHandle nullElement() {
        return InstanceHandleImpl.EMPTY_INSTANCEHANDLE;
    }

    @Override
    public InstanceHandleSet emptySet() {
      return new InstanceHandleSetImpl();
    }

    @Override
    public InstanceHandleSet emptySet(Comparator<? super InstanceHandle> comp) {
      return new InstanceHandleSetImpl(comp);
    }

    @Override
    public InstanceHandleSet value() {
        return this;
    }

    @Override
    public List<InstanceHandle> elements() {
        return Arrays.asList(toArray(new InstanceHandle[0]));
    }

}
